@@ -82,14 +82,16 @@ class SequenceGeneration():
 
         # make the inverse mapping for V/J
         if Vs is None:
-            self.invV = {ii: v[0] for ii, v in enumerate(self.genomic_data)}
+            self.invV = {ii: v[0]
+                         for ii, v in enumerate(self.genomic_data.genV)}
         else:
             self.invV = {ii: vname for ii, vname
                          in enumerate(vv for v in Vs
                                       for vv in gene_map(v, self.genomic_data)
                                       )}
         if Js is None:
-            self.invJ = {ii: j[0] for ii, j in enumerate(self.genomic_data)}
+            self.invJ = {ii: j[0]
+                         for ii, j in enumerate(self.genomic_data.genV)}
         else:
             self.invJ = {ii: jname for ii, jname
                          in enumerate(jj for j in Js
